SDIF Sound Description Interchange Format (IRCAM, Analyse/Synthèse)

# SDIFTM
Sound Description Interchange Format

This page's URL: http://sdif.sourceforge.net

The Sound Description Interchange Format (SDIF) is an established standard for the well-defined and extensible interchange of a variety of sound descriptions including spectral, sinusoidal, time-domain, and higher-level models. SDIF consists of a basic data format framework and an extensible set of standard sound descriptions. The SDIF standard has been created in collaboration by Ircam, CNMAT, and IUA-UPF.

### Documentation

- Main SDIF page at Ircam
- SDIF page at CNMAT
- SDIF wiki user-driven documentation and FAQ on the freesoftware wiki about SDIF and other Ircam Free Software
- SDIF project page at sourceforge (for developers)

### Download

- Source Releases
- CVS access for developers

### Mailing Lists

- sdif@ircam.fr (for users) usage, discussion, announcements
- sdif-devel (for developers) discussions about developing the SDIF libary and tools
- sdif-cvs (for developers) CVS-logs of changes to the code base (HINT: subscribe with your sourceforge member e-mail)

SDIF is a registered trademark, registered September 23, 1999 at INPI (Institut National de la Proprieté Industrielle), Paris, France for IRCAM - Centre Georges Pompidou, registration number 99/814815.